r163 - in /debtorrent/trunk: debtorrent-client.py debtorrent-tracker.py docs/epydoc.config setup.py

camrdale-guest at users.alioth.debian.org camrdale-guest at users.alioth.debian.org
Fri Jul 13 21:47:50 UTC 2007


Author: camrdale-guest
Date: Fri Jul 13 21:47:49 2007
New Revision: 163

URL: http://svn.debian.org/wsvn/debtorrent/?sc=1&rev=163
Log:
A few more minor changes for renaming the scripts.

Modified:
    debtorrent/trunk/debtorrent-client.py
    debtorrent/trunk/debtorrent-tracker.py
    debtorrent/trunk/docs/epydoc.config
    debtorrent/trunk/setup.py

Modified: debtorrent/trunk/debtorrent-client.py
URL: http://svn.debian.org/wsvn/debtorrent/debtorrent/trunk/debtorrent-client.py?rev=163&op=diff
==============================================================================
--- debtorrent/trunk/debtorrent-tracker.py (original)
+++ debtorrent/trunk/debtorrent-tracker.py Fri Jul 13 21:47:49 2007
@@ -27,7 +27,7 @@
         import profile, pstats
         p = profile.Profile()
         p.runcall(track, argv[1:])
-        p.dump_stats('bttrack.pstat')
+        p.dump_stats('debtorrent-tracker.pstat')
 #        pstats.Stats(p).strip_dirs().sort_stats('cumulative').print_stats()
         pstats.Stats(p).strip_dirs().sort_stats('time').print_stats()
     else:

Modified: debtorrent/trunk/docs/epydoc.config
URL: http://svn.debian.org/wsvn/debtorrent/debtorrent/trunk/docs/epydoc.config?rev=163&op=diff
==============================================================================
--- debtorrent/trunk/docs/epydoc.config (original)
+++ debtorrent/trunk/docs/epydoc.config Fri Jul 13 21:47:49 2007
@@ -3,7 +3,7 @@
 # The list of objects to document.  Objects can be named using
 # dotted names, module filenames, or package directory names.
 # Alases for this option include "objects" and "values".
-modules: DebTorrent btdownloadheadless.py btlaunchmany.py bttrack.py btcompletedir.py btcopyannounce.py btmakemetafile.py btreannounce.py btrename.py btsetdebmirrors.py btshowmetainfo.py test.py
+modules: DebTorrent btdownloadheadless.py btlaunchmany.py btcompletedir.py btcopyannounce.py btmakemetafile.py btreannounce.py btrename.py btsetdebmirrors.py btshowmetainfo.py test.py debtorrent-client.py debtorrent-tracker.py
 
 # The type of output that should be generated.  Should be one
 # of: html, text, latex, dvi, ps, pdf.

Modified: debtorrent/trunk/setup.py
URL: http://svn.debian.org/wsvn/debtorrent/debtorrent/trunk/setup.py?rev=163&op=diff
==============================================================================
--- debtorrent/trunk/setup.py (original)
+++ debtorrent/trunk/setup.py Fri Jul 13 21:47:49 2007
@@ -29,9 +29,10 @@
     
     packages = ["DebTorrent","DebTorrent.BT1"],
 
-    scripts = ["btdownloadheadless.py", 
-        "bttrack.py", "btmakemetafile.py", "btlaunchmany.py", "btcompletedir.py",
-        "btreannounce.py", "btrename.py", "btshowmetainfo.py",
-        'btcopyannounce.py', 'btsetdebmirrors.py', 'test.py',
+    scripts = ["btdownloadheadless.py", "btlaunchmany.py", 
+               "btmakemetafile.py", "btcompletedir.py", "btreannounce.py", 
+               "btrename.py", "btshowmetainfo.py", 'btcopyannounce.py',
+               'btsetdebmirrors.py', 'test.py',
+               'debtorrent-client.py', 'debtorrent-tracker.py'
         ]
     )




More information about the Debtorrent-commits mailing list
--- debtorrent/trunk/debtorrent-client.py (original)
+++ debtorrent/trunk/debtorrent-client.py Fri Jul 13 21:47:49 2007
@@ -4,9 +4,9 @@
 #
 # $Id$
 
 """A multiple downloader daemon for debtorrent.
 
-This script implements a daemon for managing multiple 
+This script implements a client daemon for managing multiple 
 debtorrent downloads.
 
 """
@@ -126,13 +126,13 @@
     defaults.extend(defaults_many)
     configdefaults = {}
     try:
-        configdir = ConfigDir('debtorrent')
+        configdir = ConfigDir('debtorrent-client')
         defaultsToIgnore = ['configfile', 'priority']
         configdir.setDefaults(defaults,defaultsToIgnore)
         configdefaults = configdir.loadConfig(params)
         defaults.append(('save_options',0,
          "whether to save the current options as the new default configuration " +
-         "(only for debtorrent.py)"))
+         "(only for debtorrent-client.py)"))
         config, args = parseargs(params, defaults, 0, 0, configdefaults)
         configdir.setCacheDir(config['cache_dir'])
         if config['save_options']:
@@ -140,7 +140,7 @@
         configdir.deleteOldCacheData(config['expire_cache_data'])
     except ValueError, e:
         print 'error: ' + str(e) + '\n'
-        print "Usage: debtorrent.py <global options>\n"
+        print "Usage: debtorrent-client.py <global options>\n"
         print get_usage(defaults, 80, configdefaults)
         exit(1)
     except IOError, e:
@@ -161,7 +161,7 @@
         import profile, pstats
         p = profile.Profile()
         p.runcall(run, argv[2:])
-        p.dump_stats('debtorrent.pstat')
+        p.dump_stats('debtorrent-client.pstat')
         # pstats.Stats(p).strip_dirs().sort_stats('cumulative').print_stats()
         pstats.Stats(p).strip_dirs().sort_stats('time').print_stats()
     elif argv[1:2] == ['--foreground']:
@@ -4,9 +4,9 @@
 # $Id$
 
-"""A multiple downloader daemon for debtorrent.
+"""A multiple downloader client daemon for debtorrent.
 

Modified: debtorrent/trunk/debtorrent-tracker.py
URL: http://svn.debian.org/wsvn/debtorrent/debtorrent/trunk/debtorrent-tracker.py?rev=163&op=diff
==============================================================================